# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.embedding_response import EmbeddingResponse
from .raw_client import AsyncRawEmbedClient, RawEmbedClient
from .tasks.client import AsyncTasksClient, TasksClient
from .v_2.client import AsyncV2Client, V2Client

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class EmbedClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEmbedClient(client_wrapper=client_wrapper)
        self.tasks = TasksClient(client_wrapper=client_wrapper)

        self.v_2 = V2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEmbedClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEmbedClient
        """
        return self._raw_client

    def create(
        self,
        *,
        model_name: str,
        text: typing.Optional[str] = OMIT,
        image_url: typing.Optional[str] = OMIT,
        image_file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[core.File] = OMIT,
        audio_start_offset_sec: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmbeddingResponse:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>

        This method creates embeddings for text, image, and audio content.

        Ensure your media files meet the following requirements:
        - [Audio files](/v1.3/docs/concepts/models/marengo#audio-requirements).
        - [Image files](/v1.3/docs/concepts/models/marengo#image-requirements).

        Parameters for embeddings:
        - **Common parameters**:
          - `model_name`: The video understanding model you want to use. Example: "marengo3.0".
        - **Text embeddings**:
          - `text`: Text for which to create an embedding.
        - **Image embeddings**:
          Provide one of the following:
          - `image_url`: Publicly accessible URL of your image file.
          - `image_file`:  Local image file.
        - **Audio embeddings**:
          Provide one of the following:
          - `audio_url`: Publicly accessible URL of your audio file.
          - `audio_file`: Local audio file.

        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - You can create multiple types of embeddings in a single API call.
        - Audio embeddings combine generic sound and human speech in a single embedding. For videos with transcriptions, you can retrieve transcriptions and then [create text embeddings](/v1.3/api-reference/create-embeddings-v1/text-image-audio-embeddings/create-text-image-audio-embeddings) from these
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.

        text : typing.Optional[str]
            The text for which you wish to create an embedding.

            **Example**: "Man with a dog crossing the street"

        image_url : typing.Optional[str]
            The publicly accessible URL of the image for which you wish to create an embedding. This parameter is required for image embeddings if `image_file` is not provided.

        image_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            The publicly accessible URL of the audio file for which you wish to creae an embedding. This parameter is required for audio embeddings if `audio_file` is not provided.

        audio_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_start_offset_sec : typing.Optional[float]
            Specifies the start time, in seconds, from which the platform generates the audio embeddings. This parameter allows you to skip the initial portion of the audio during processing.
            **Default**: `0`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmbeddingResponse
            A text embedding has successfully been created.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.create(
            model_name="model_name",
        )
        """
        _response = self._raw_client.create(
            model_name=model_name,
            text=text,
            image_url=image_url,
            image_file=image_file,
            audio_url=audio_url,
            audio_file=audio_file,
            audio_start_offset_sec=audio_start_offset_sec,
            request_options=request_options,
        )
        return _response.data


class AsyncEmbedClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEmbedClient(client_wrapper=client_wrapper)
        self.tasks = AsyncTasksClient(client_wrapper=client_wrapper)

        self.v_2 = AsyncV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEmbedClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEmbedClient
        """
        return self._raw_client

    async def create(
        self,
        *,
        model_name: str,
        text: typing.Optional[str] = OMIT,
        image_url: typing.Optional[str] = OMIT,
        image_file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[core.File] = OMIT,
        audio_start_offset_sec: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EmbeddingResponse:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>

        This method creates embeddings for text, image, and audio content.

        Ensure your media files meet the following requirements:
        - [Audio files](/v1.3/docs/concepts/models/marengo#audio-requirements).
        - [Image files](/v1.3/docs/concepts/models/marengo#image-requirements).

        Parameters for embeddings:
        - **Common parameters**:
          - `model_name`: The video understanding model you want to use. Example: "marengo3.0".
        - **Text embeddings**:
          - `text`: Text for which to create an embedding.
        - **Image embeddings**:
          Provide one of the following:
          - `image_url`: Publicly accessible URL of your image file.
          - `image_file`:  Local image file.
        - **Audio embeddings**:
          Provide one of the following:
          - `audio_url`: Publicly accessible URL of your audio file.
          - `audio_file`: Local audio file.

        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - You can create multiple types of embeddings in a single API call.
        - Audio embeddings combine generic sound and human speech in a single embedding. For videos with transcriptions, you can retrieve transcriptions and then [create text embeddings](/v1.3/api-reference/create-embeddings-v1/text-image-audio-embeddings/create-text-image-audio-embeddings) from these
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.

        text : typing.Optional[str]
            The text for which you wish to create an embedding.

            **Example**: "Man with a dog crossing the street"

        image_url : typing.Optional[str]
            The publicly accessible URL of the image for which you wish to create an embedding. This parameter is required for image embeddings if `image_file` is not provided.

        image_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            The publicly accessible URL of the audio file for which you wish to creae an embedding. This parameter is required for audio embeddings if `audio_file` is not provided.

        audio_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_start_offset_sec : typing.Optional[float]
            Specifies the start time, in seconds, from which the platform generates the audio embeddings. This parameter allows you to skip the initial portion of the audio during processing.
            **Default**: `0`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EmbeddingResponse
            A text embedding has successfully been created.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.embed.create(
                model_name="model_name",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            model_name=model_name,
            text=text,
            image_url=image_url,
            image_file=image_file,
            audio_url=audio_url,
            audio_file=audio_file,
            audio_start_offset_sec=audio_start_offset_sec,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .embedding_data_embedding_option import EmbeddingDataEmbeddingOption
from .embedding_data_embedding_scope import EmbeddingDataEmbeddingScope


class EmbeddingData(UniversalBaseModel):
    """
    An embedding with its metadata.
    """

    embedding: typing.List[float] = pydantic.Field()
    """
    The embedding vector for the content.
    """

    embedding_option: typing.Optional[EmbeddingDataEmbeddingOption] = pydantic.Field(default=None)
    """
    The modality used to generate this embedding.
    
      **Values**:
     - `visual`: Embedding based on visual content (video only)
     - `audio`: Embedding based on audio content
     - `transcription`: Embedding based on transcribed speech
     - `fused`: Embedding based on a combination of the modalities specified in the request. The platform returns this embedding only for video and audio content, and only when the `embedding_type` parameter in the request includes `fused_embedding`.
     - `null`: For text and image embeddings
    """

    embedding_scope: typing.Optional[EmbeddingDataEmbeddingScope] = pydantic.Field(default=None)
    """
    The scope for which the embedding was generated.
    
    **Values**:
    - `clip`: Embedding for a segment
    - `asset`: Embedding for the entire file. Use this scope for videos up to 10-30 seconds to maintain optimal performance.
    - `null`: For text and image embeddings
    """

    start_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The start time in seconds for this segment. This field is `null` for text and image embeddings.
    """

    end_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The end time in seconds for this segment. This field is `null` for text and image embeddings.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AnalyzeTaskWebhookInfo(UniversalBaseModel):
    """
    The delivery status of a webhook endpoint.
    """

    url: str = pydantic.Field()
    """
    The URL of the webhook endpoint that received the delivery.
    """

    delivered: bool = pydantic.Field()
    """
    Indicates whether the platform successfully delivered the webhook.
    """

    attempts: int = pydantic.Field()
    """
    The total number of delivery attempts for this URL.
    """

    last_error: typing.Optional[str] = pydantic.Field(default=None)
    """
    The error message from the last failed delivery attempt. This field appears only when `delivered` is `false`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ImportLogFailedFilesItem(UniversalBaseModel):
    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the video file that failed to import.
    """

    error_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    A human-readable error message.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audio_segmentation_fixed import AudioSegmentationFixed
from .audio_segmentation_strategy import AudioSegmentationStrategy


class AudioSegmentation(UniversalBaseModel):
    """
    Specifies how the platform divides the audio into segments.
    """

    strategy: AudioSegmentationStrategy
    fixed: AudioSegmentationFixed = pydantic.Field()
    """
    Configuration for fixed segmentation.
    
    This object is required when the `strategy` field is `fixed`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    IndexedAssetsCreateResponse,
    IndexedAssetsListRequestStatusItem,
    IndexedAssetsListRequestUserMetadataValue,
    IndexedAssetsListResponse,
    IndexedAssetsRetrieveRequestEmbeddingOptionItem,
)

__all__ = [
    "IndexedAssetsCreateResponse",
    "IndexedAssetsListRequestStatusItem",
    "IndexedAssetsListRequestUserMetadataValue",
    "IndexedAssetsListResponse",
    "IndexedAssetsRetrieveRequestEmbeddingOptionItem",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .expires_at import ExpiresAt


class PresignedUrlChunk(UniversalBaseModel):
    chunk_index: typing.Optional[int] = pydantic.Field(default=None)
    """
    The index of this chunk.
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The presigned URL for uploading this chunk. Each URL can only be used once and expires after 1 hour.
    """

    expires_at: typing.Optional[ExpiresAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .bulk_create_entity_response_entities_item import BulkCreateEntityResponseEntitiesItem
from .bulk_create_entity_response_errors_item import BulkCreateEntityResponseErrorsItem


class BulkCreateEntityResponse(UniversalBaseModel):
    """
    An object that represents the response from a bulk entity creation operation. This response summarizes the outcome, including the number of entities successfully created and any errors encountered during the process.
    """

    success_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of entities that were successfully created.
    """

    failed_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of entities that failed to be created due to errors, such as missing assets.
    """

    entities: typing.Optional[typing.List[BulkCreateEntityResponseEntitiesItem]] = pydantic.Field(default=None)
    """
    An array of objects representing the entities that were successfully created. Each object includes the unique identifier, name, and current status.
    """

    errors: typing.Optional[typing.List[BulkCreateEntityResponseErrorsItem]] = pydantic.Field(default=None)
    """
    An array of error objects for entities that failed to be created. Each error object provides details about the failure, including the index of the entity in the original request, the entity's name, and the reason for the failure.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ... import core
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.pagination import AsyncPager, SyncPager
from ...core.request_options import RequestOptions
from ...types.media_embedding_task import MediaEmbeddingTask
from .raw_client import AsyncRawTasksClient, RawTasksClient
from .types.tasks_create_request_video_embedding_scope_item import TasksCreateRequestVideoEmbeddingScopeItem
from .types.tasks_create_response import TasksCreateResponse
from .types.tasks_retrieve_request_embedding_option_item import TasksRetrieveRequestEmbeddingOptionItem
from .types.tasks_retrieve_response import TasksRetrieveResponse
from .types.tasks_status_response import TasksStatusResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TasksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTasksClient
        """
        return self._raw_client

    def list(
        self,
        *,
        started_at: typing.Optional[str] = None,
        ended_at: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[MediaEmbeddingTask]:
        """
        <Note title="Note">
          This method will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        This method returns a list of the video embedding tasks in your account. The platform returns your video embedding tasks sorted by creation date, with the newest at the top of the list.

        <Note title="Notes">
        - Video embeddings are stored for seven days
        - When you invoke this method without specifying the `started_at` and `ended_at` parameters, the platform returns all the video embedding tasks created within the last seven days.
        </Note>

        Parameters
        ----------
        started_at : typing.Optional[str]
            Retrieve the embedding tasks that were created after the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        ended_at : typing.Optional[str]
            Retrieve the embedding tasks that were created before the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        status : typing.Optional[str]
            Filter the embedding tasks by their current status.

            **Values**: `processing`, `ready`, or `failed`.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[MediaEmbeddingTask]
            A list of async embedding tasks has successfully been retrieved.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        response = client.embed.tasks.list(
            started_at="2024-03-01T00:00:00Z",
            ended_at="2024-03-01T00:00:00Z",
            status="processing",
            page=1,
            page_limit=10,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.list(
            started_at=started_at,
            ended_at=ended_at,
            status=status,
            page=page,
            page_limit=page_limit,
            request_options=request_options,
        )

    def create(
        self,
        *,
        model_name: str,
        video_file: typing.Optional[core.File] = OMIT,
        video_url: typing.Optional[str] = OMIT,
        video_start_offset_sec: typing.Optional[float] = OMIT,
        video_end_offset_sec: typing.Optional[float] = OMIT,
        video_clip_length: typing.Optional[float] = OMIT,
        video_embedding_scope: typing.Optional[typing.List[TasksCreateRequestVideoEmbeddingScopeItem]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksCreateResponse:
        """
        
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        
        This method creates a new video embedding task that uploads a video to the platform and creates one or multiple video embeddings.
        
        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>
        
        Upload options:
        - **Local file**: Use the `video_file` parameter
        - **Publicly accessible URL**: Use the `video_url` parameter.
        
        Specify at least one option. If both are provided, `video_url` takes precedence.
        
        Your video files must meet the [requirements](/v1.3/docs/concepts/models/marengo#video-file-requirements).
        This endpoint allows you to upload files up to 2 GB in size.  To upload larger files, use the [Multipart Upload API](/v1.3/api-reference/upload-content/multipart-uploads)
        
        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - Video embeddings are stored for seven days.
        </Note>
        
        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.
        
        video_file : typing.Optional[core.File]
            See core.File for more documentation
        
        video_url : typing.Optional[str]
            Specify this parameter to upload a video from a publicly accessible URL.
        
        video_start_offset_sec : typing.Optional[float]
            The start offset in seconds from the beginning of the video where processing should begin. Specifying 0 means starting from the beginning of the video.
            
            **Default**: 0
            **Min**: 0
            **Max**: Duration of the video minus video_clip_length
        
        video_end_offset_sec : typing.Optional[float]
            The end offset in seconds from the beginning of the video where processing should stop.
            
            Ensure the following when you specify this parameter:
            - The end offset does not exceed the total duration of the video file.
            - The end offset is greater than the start offset.
            - You must set both the start and end offsets. Setting only one of these offsets is not permitted, resulting in an error.
            
            **Min**: video_start_offset + video_clip_length
            **Max**: Duration of the video file
        
        video_clip_length : typing.Optional[float]
            The desired duration in seconds for each clip for which the platform generates an embedding. Ensure that the clip length does not exceed the interval between the start and end offsets.
            
            **Default**: 6
            **Min**: 2
            **Max**: 10
        
        video_embedding_scope : typing.Optional[typing.List[TasksCreateRequestVideoEmbeddingScopeItem]]
            Defines the scope of video embedding generation. Valid values are the following:
            - `clip`: Creates embeddings for each video segment of `video_clip_length` seconds, from `video_start_offset_sec` to `video_end_offset_sec`.
            - `clip` and `video`: Creates embeddings for video segments and the entire video. Use the `video` scope for videos up to 10-30 seconds to maintain optimal performance.
            
            To create embeddings for segments and the entire video in the same request, include this parameter twice as shown below:
            
            ```json
            --form video_embedding_scope=clip \
            --form video_embedding_scope=video
            ```
            
            **Default**: `clip`
        
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.
        
        Returns
        -------
        TasksCreateResponse
            A video embedding task has successfully been created.
        
        Examples
        --------
        from twelvelabs import TwelveLabs
        
        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.tasks.create(
            model_name="model_name",
        )
        """
        _response = self._raw_client.create(
            model_name=model_name,
            video_file=video_file,
            video_url=video_url,
            video_start_offset_sec=video_start_offset_sec,
            video_end_offset_sec=video_end_offset_sec,
            video_clip_length=video_clip_length,
            video_embedding_scope=video_embedding_scope,
            request_options=request_options,
        )
        return _response.data

    def status(self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> TasksStatusResponse:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        This method retrieves the status of a video embedding task. Check the task status of a video embedding task to determine when you can retrieve the embedding.

        A task can have one of the following statuses:
        - `processing`: The platform is creating the embeddings.
        - `ready`:  Processing is complete. Retrieve the embeddings by invoking the [`GET`](/v1.3/api-reference/create-embeddings-v1/video-embeddings/retrieve-video-embeddings) method of the `/embed/tasks/{task_id} endpoint`.
        - `failed`: The task could not be completed, and the embeddings haven't been created.

        Parameters
        ----------
        task_id : str
            The unique identifier of your video embedding task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksStatusResponse
            The status of your video embedding task has been retrieved.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.tasks.status(
            task_id="663da73b31cdd0c1f638a8e6",
        )
        """
        _response = self._raw_client.status(task_id, request_options=request_options)
        return _response.data

    def retrieve(
        self,
        task_id: str,
        *,
        embedding_option: typing.Optional[
            typing.Union[
                TasksRetrieveRequestEmbeddingOptionItem, typing.Sequence[TasksRetrieveRequestEmbeddingOptionItem]
            ]
        ] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksRetrieveResponse:
        """
        This method retrieves embeddings for a specific video embedding task. Ensure the task status is `ready` before invoking this method. Refer to the [Retrieve the status of a video embedding tasks](/v1.3/api-reference/create-embeddings-v1/video-embeddings/retrieve-video-embedding-task-status) page for instructions on checking the task status.

        Parameters
        ----------
        task_id : str
            The unique identifier of your video embedding task.

        embedding_option : typing.Optional[typing.Union[TasksRetrieveRequestEmbeddingOptionItem, typing.Sequence[TasksRetrieveRequestEmbeddingOptionItem]]]
            Specifies which types of embeddings to retrieve. Values: `visual`, `audio`, `transcription`. For details, see the [Embedding options](/v1.3/docs/concepts/modalities#embedding-options) section.

            <Note title="Note">
            The platform returns all available embeddings when you omit this parameter.
            </Note>

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksRetrieveResponse
            Video embeddings have successfully been retrieved.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.embed.tasks.retrieve(
            task_id="663da73b31cdd0c1f638a8e6",
        )
        """
        _response = self._raw_client.retrieve(
            task_id, embedding_option=embedding_option, request_options=request_options
        )
        return _response.data


class AsyncTasksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTasksClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        started_at: typing.Optional[str] = None,
        ended_at: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[MediaEmbeddingTask]:
        """
        <Note title="Note">
          This method will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        This method returns a list of the video embedding tasks in your account. The platform returns your video embedding tasks sorted by creation date, with the newest at the top of the list.

        <Note title="Notes">
        - Video embeddings are stored for seven days
        - When you invoke this method without specifying the `started_at` and `ended_at` parameters, the platform returns all the video embedding tasks created within the last seven days.
        </Note>

        Parameters
        ----------
        started_at : typing.Optional[str]
            Retrieve the embedding tasks that were created after the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        ended_at : typing.Optional[str]
            Retrieve the embedding tasks that were created before the given date and time, expressed in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ").

        status : typing.Optional[str]
            Filter the embedding tasks by their current status.

            **Values**: `processing`, `ready`, or `failed`.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[MediaEmbeddingTask]
            A list of async embedding tasks has successfully been retrieved.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            response = await client.embed.tasks.list(
                started_at="2024-03-01T00:00:00Z",
                ended_at="2024-03-01T00:00:00Z",
                status="processing",
                page=1,
                page_limit=10,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.list(
            started_at=started_at,
            ended_at=ended_at,
            status=status,
            page=page,
            page_limit=page_limit,
            request_options=request_options,
        )

    async def create(
        self,
        *,
        model_name: str,
        video_file: typing.Optional[core.File] = OMIT,
        video_url: typing.Optional[str] = OMIT,
        video_start_offset_sec: typing.Optional[float] = OMIT,
        video_end_offset_sec: typing.Optional[float] = OMIT,
        video_clip_length: typing.Optional[float] = OMIT,
        video_embedding_scope: typing.Optional[typing.List[TasksCreateRequestVideoEmbeddingScopeItem]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksCreateResponse:
        """
        
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        
        This method creates a new video embedding task that uploads a video to the platform and creates one or multiple video embeddings.
        
        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>
        
        Upload options:
        - **Local file**: Use the `video_file` parameter
        - **Publicly accessible URL**: Use the `video_url` parameter.
        
        Specify at least one option. If both are provided, `video_url` takes precedence.
        
        Your video files must meet the [requirements](/v1.3/docs/concepts/models/marengo#video-file-requirements).
        This endpoint allows you to upload files up to 2 GB in size.  To upload larger files, use the [Multipart Upload API](/v1.3/api-reference/upload-content/multipart-uploads)
        
        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - Video embeddings are stored for seven days.
        </Note>
        
        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.
        
        video_file : typing.Optional[core.File]
            See core.File for more documentation
        
        video_url : typing.Optional[str]
            Specify this parameter to upload a video from a publicly accessible URL.
        
        video_start_offset_sec : typing.Optional[float]
            The start offset in seconds from the beginning of the video where processing should begin. Specifying 0 means starting from the beginning of the video.
            
            **Default**: 0
            **Min**: 0
            **Max**: Duration of the video minus video_clip_length
        
        video_end_offset_sec : typing.Optional[float]
            The end offset in seconds from the beginning of the video where processing should stop.
            
            Ensure the following when you specify this parameter:
            - The end offset does not exceed the total duration of the video file.
            - The end offset is greater than the start offset.
            - You must set both the start and end offsets. Setting only one of these offsets is not permitted, resulting in an error.
            
            **Min**: video_start_offset + video_clip_length
            **Max**: Duration of the video file
        
        video_clip_length : typing.Optional[float]
            The desired duration in seconds for each clip for which the platform generates an embedding. Ensure that the clip length does not exceed the interval between the start and end offsets.
            
            **Default**: 6
            **Min**: 2
            **Max**: 10
        
        video_embedding_scope : typing.Optional[typing.List[TasksCreateRequestVideoEmbeddingScopeItem]]
            Defines the scope of video embedding generation. Valid values are the following:
            - `clip`: Creates embeddings for each video segment of `video_clip_length` seconds, from `video_start_offset_sec` to `video_end_offset_sec`.
            - `clip` and `video`: Creates embeddings for video segments and the entire video. Use the `video` scope for videos up to 10-30 seconds to maintain optimal performance.
            
            To create embeddings for segments and the entire video in the same request, include this parameter twice as shown below:
            
            ```json
            --form video_embedding_scope=clip \
            --form video_embedding_scope=video
            ```
            
            **Default**: `clip`
        
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.
        
        Returns
        -------
        TasksCreateResponse
            A video embedding task has successfully been created.
        
        Examples
        --------
        import asyncio
        
        from twelvelabs import AsyncTwelveLabs
        
        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )
        
        
        async def main() -> None:
            await client.embed.tasks.create(
                model_name="model_name",
            )
        
        
        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            model_name=model_name,
            video_file=video_file,
            video_url=video_url,
            video_start_offset_sec=video_start_offset_sec,
            video_end_offset_sec=video_end_offset_sec,
            video_clip_length=video_clip_length,
            video_embedding_scope=video_embedding_scope,
            request_options=request_options,
        )
        return _response.data

    async def status(
        self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TasksStatusResponse:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>
        This method retrieves the status of a video embedding task. Check the task status of a video embedding task to determine when you can retrieve the embedding.

        A task can have one of the following statuses:
        - `processing`: The platform is creating the embeddings.
        - `ready`:  Processing is complete. Retrieve the embeddings by invoking the [`GET`](/v1.3/api-reference/create-embeddings-v1/video-embeddings/retrieve-video-embeddings) method of the `/embed/tasks/{task_id} endpoint`.
        - `failed`: The task could not be completed, and the embeddings haven't been created.

        Parameters
        ----------
        task_id : str
            The unique identifier of your video embedding task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksStatusResponse
            The status of your video embedding task has been retrieved.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.embed.tasks.status(
                task_id="663da73b31cdd0c1f638a8e6",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.status(task_id, request_options=request_options)
        return _response.data

    async def retrieve(
        self,
        task_id: str,
        *,
        embedding_option: typing.Optional[
            typing.Union[
                TasksRetrieveRequestEmbeddingOptionItem, typing.Sequence[TasksRetrieveRequestEmbeddingOptionItem]
            ]
        ] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksRetrieveResponse:
        """
        This method retrieves embeddings for a specific video embedding task. Ensure the task status is `ready` before invoking this method. Refer to the [Retrieve the status of a video embedding tasks](/v1.3/api-reference/create-embeddings-v1/video-embeddings/retrieve-video-embedding-task-status) page for instructions on checking the task status.

        Parameters
        ----------
        task_id : str
            The unique identifier of your video embedding task.

        embedding_option : typing.Optional[typing.Union[TasksRetrieveRequestEmbeddingOptionItem, typing.Sequence[TasksRetrieveRequestEmbeddingOptionItem]]]
            Specifies which types of embeddings to retrieve. Values: `visual`, `audio`, `transcription`. For details, see the [Embedding options](/v1.3/docs/concepts/modalities#embedding-options) section.

            <Note title="Note">
            The platform returns all available embeddings when you omit this parameter.
            </Note>

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksRetrieveResponse
            Video embeddings have successfully been retrieved.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.embed.tasks.retrieve(
                task_id="663da73b31cdd0c1f638a8e6",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(
            task_id, embedding_option=embedding_option, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .base_segment import BaseSegment
from .end_offset_sec import EndOffsetSec
from .start_offset_sec import StartOffsetSec


class AudioSegment(BaseSegment):
    """
    An object that contains the audio embedding and its start time.
    """

    start_offset_sec: typing.Optional[StartOffsetSec] = None
    end_offset_sec: typing.Optional[EndOffsetSec] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .indexes_create_request_models_item import IndexesCreateRequestModelsItem
from .indexes_create_response import IndexesCreateResponse
from .indexes_list_response import IndexesListResponse

__all__ = ["IndexesCreateRequestModelsItem", "IndexesCreateResponse", "IndexesListResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import jsonable_encoder
from ...core.pagination import AsyncPager, BaseHttpResponse, SyncPager
from ...core.pydantic_utilities import parse_obj_as
from ...core.request_options import RequestOptions
from ...core.serialization import convert_and_respect_annotation_metadata
from ...errors.bad_request_error import BadRequestError
from ...errors.not_found_error import NotFoundError
from ...types.user_metadata import UserMetadata
from ...types.video_vector import VideoVector
from .types.videos_list_request_user_metadata_value import VideosListRequestUserMetadataValue
from .types.videos_list_response import VideosListResponse
from .types.videos_retrieve_request_embedding_option_item import VideosRetrieveRequestEmbeddingOptionItem
from .types.videos_retrieve_response import VideosRetrieveResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawVideosClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        index_id: str,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        sort_by: typing.Optional[str] = None,
        sort_option: typing.Optional[str] = None,
        filename: typing.Optional[str] = None,
        duration: typing.Optional[float] = None,
        fps: typing.Optional[float] = None,
        width: typing.Optional[float] = None,
        height: typing.Optional[int] = None,
        size: typing.Optional[float] = None,
        created_at: typing.Optional[str] = None,
        updated_at: typing.Optional[str] = None,
        user_metadata: typing.Optional[typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[VideoVector]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [List indexed assets](/v1.3/api-reference/index-content/list) method.</Info>

        This method returns a list of the videos in the specified index. By default, the platform returns your videos sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index for which the platform will retrieve the videos.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        sort_by : typing.Optional[str]
            The field to sort on. The following options are available:
            - `updated_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the item was updated.
            - `created_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the item was created.

            **Default**: `created_at`.

        sort_option : typing.Optional[str]
            The sorting direction. The following options are available:
            - `asc`
            - `desc`

            **Default**: `desc`.

        filename : typing.Optional[str]
            Filter by filename.

        duration : typing.Optional[float]
            Filter by duration. Expressed in seconds.

        fps : typing.Optional[float]
            Filter by frames per second.

        width : typing.Optional[float]
            Filter by width.

        height : typing.Optional[int]
            Filter by height.

        size : typing.Optional[float]
            Filter by size. Expressed in bytes.

        created_at : typing.Optional[str]
            Filter videos by the creation date and time of their associated indexing tasks, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"). The platform returns the videos whose indexing tasks were created on the specified date at or after the given time.

        updated_at : typing.Optional[str]
            This filter applies only to videos updated using the [`PUT`](/v1.3/api-reference/videos/update) method of the `/indexes/{index-id}/videos/{video-id}` endpoint. It filters videos by the last update date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"). The platform returns the video indexing tasks that were last updated on the specified date at or after the given time.

        user_metadata : typing.Optional[typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]]]
            To enable filtering by custom fields, you must first add user-defined metadata to your video by calling the [`PUT`](/v1.3/api-reference/videos/update) method of the `/indexes/:index-id/videos/:video-id` endpoint.

            Examples:
            - To filter on a string: `?category=recentlyAdded`
            - To filter on an integer: `?batchNumber=5`
            - To filter on a float: `?rating=9.3`
            - To filter on a boolean: `?needsReview=true`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[VideoVector]
            The video vectors in the specified index have successfully been retrieved.
        """
        page = page if page is not None else 1

        _response = self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos",
            method="GET",
            params={
                "page": page,
                "page_limit": page_limit,
                "sort_by": sort_by,
                "sort_option": sort_option,
                "filename": filename,
                "duration": duration,
                "fps": fps,
                "width": width,
                "height": height,
                "size": size,
                "created_at": created_at,
                "updated_at": updated_at,
                "user_metadata": convert_and_respect_annotation_metadata(
                    object_=user_metadata,
                    annotation=typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]],
                    direction="write",
                ),
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _parsed_response = typing.cast(
                    VideosListResponse,
                    parse_obj_as(
                        type_=VideosListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                _items = _parsed_response.data
                _has_next = True
                _get_next = lambda: self.list(
                    index_id,
                    page=page + 1,
                    page_limit=page_limit,
                    sort_by=sort_by,
                    sort_option=sort_option,
                    filename=filename,
                    duration=duration,
                    fps=fps,
                    width=width,
                    height=height,
                    size=size,
                    created_at=created_at,
                    updated_at=updated_at,
                    user_metadata=user_metadata,
                    request_options=request_options,
                )
                return SyncPager(
                    has_next=_has_next, items=_items, get_next=_get_next, response=BaseHttpResponse(response=_response)
                )
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def retrieve(
        self,
        index_id: str,
        video_id: str,
        *,
        embedding_option: typing.Optional[
            typing.Union[
                VideosRetrieveRequestEmbeddingOptionItem, typing.Sequence[VideosRetrieveRequestEmbeddingOptionItem]
            ]
        ] = None,
        transcription: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[VideosRetrieveResponse]:
        """
        <Info> This method will be deprecated in a future version. New implementations should use the [Retrieve an indexed asset](/v1.3/api-reference/index-content/retrieve) method.</Info>

        This method retrieves information about the specified video.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to retrieve.

        embedding_option : typing.Optional[typing.Union[VideosRetrieveRequestEmbeddingOptionItem, typing.Sequence[VideosRetrieveRequestEmbeddingOptionItem]]]
            Specifies which types of embeddings to retrieve. Values: `visual`, `audio`, `transcription`. For details, see the [Embedding options](/v1.3/docs/concepts/modalities#embedding-options) section.

            <Note title="Note">
            To retrieve embeddings for a video, it must be indexed using the Marengo video understanding model. For details on enabling this model for an index, see the [Create an index](/reference/create-index) page.
            </Note>

        transcription : typing.Optional[bool]
            The parameter indicates whether to retrieve a transcription of the spoken words for the indexed video.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[VideosRetrieveResponse]
            The specified video information has successfully been retrieved.
        """
        _response = self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="GET",
            params={
                "embedding_option": embedding_option,
                "transcription": transcription,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VideosRetrieveResponse,
                    parse_obj_as(
                        type_=VideosRetrieveResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, index_id: str, video_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [Delete an indexed asset](/v1.3/api-reference/index-content/delete) method.</Info>

        This method deletes all the information about the specified indexed video. This action cannot be undone.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        index_id: str,
        video_id: str,
        *,
        user_metadata: typing.Optional[UserMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [Partial update indexed asset](/v1.3/api-reference/index-content/update) method.</Info>

        This method updates one or more fields of the metadata of a video. Also, can delete a field by setting it to `null`.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to update.

        user_metadata : typing.Optional[UserMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="PATCH",
            json={
                "user_metadata": user_metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawVideosClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        index_id: str,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        sort_by: typing.Optional[str] = None,
        sort_option: typing.Optional[str] = None,
        filename: typing.Optional[str] = None,
        duration: typing.Optional[float] = None,
        fps: typing.Optional[float] = None,
        width: typing.Optional[float] = None,
        height: typing.Optional[int] = None,
        size: typing.Optional[float] = None,
        created_at: typing.Optional[str] = None,
        updated_at: typing.Optional[str] = None,
        user_metadata: typing.Optional[typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[VideoVector]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [List indexed assets](/v1.3/api-reference/index-content/list) method.</Info>

        This method returns a list of the videos in the specified index. By default, the platform returns your videos sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index for which the platform will retrieve the videos.

        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        sort_by : typing.Optional[str]
            The field to sort on. The following options are available:
            - `updated_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the item was updated.
            - `created_at`: Sorts by the time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the item was created.

            **Default**: `created_at`.

        sort_option : typing.Optional[str]
            The sorting direction. The following options are available:
            - `asc`
            - `desc`

            **Default**: `desc`.

        filename : typing.Optional[str]
            Filter by filename.

        duration : typing.Optional[float]
            Filter by duration. Expressed in seconds.

        fps : typing.Optional[float]
            Filter by frames per second.

        width : typing.Optional[float]
            Filter by width.

        height : typing.Optional[int]
            Filter by height.

        size : typing.Optional[float]
            Filter by size. Expressed in bytes.

        created_at : typing.Optional[str]
            Filter videos by the creation date and time of their associated indexing tasks, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"). The platform returns the videos whose indexing tasks were created on the specified date at or after the given time.

        updated_at : typing.Optional[str]
            This filter applies only to videos updated using the [`PUT`](/v1.3/api-reference/videos/update) method of the `/indexes/{index-id}/videos/{video-id}` endpoint. It filters videos by the last update date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"). The platform returns the video indexing tasks that were last updated on the specified date at or after the given time.

        user_metadata : typing.Optional[typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]]]
            To enable filtering by custom fields, you must first add user-defined metadata to your video by calling the [`PUT`](/v1.3/api-reference/videos/update) method of the `/indexes/:index-id/videos/:video-id` endpoint.

            Examples:
            - To filter on a string: `?category=recentlyAdded`
            - To filter on an integer: `?batchNumber=5`
            - To filter on a float: `?rating=9.3`
            - To filter on a boolean: `?needsReview=true`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[VideoVector]
            The video vectors in the specified index have successfully been retrieved.
        """
        page = page if page is not None else 1

        _response = await self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos",
            method="GET",
            params={
                "page": page,
                "page_limit": page_limit,
                "sort_by": sort_by,
                "sort_option": sort_option,
                "filename": filename,
                "duration": duration,
                "fps": fps,
                "width": width,
                "height": height,
                "size": size,
                "created_at": created_at,
                "updated_at": updated_at,
                "user_metadata": convert_and_respect_annotation_metadata(
                    object_=user_metadata,
                    annotation=typing.Dict[str, typing.Optional[VideosListRequestUserMetadataValue]],
                    direction="write",
                ),
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _parsed_response = typing.cast(
                    VideosListResponse,
                    parse_obj_as(
                        type_=VideosListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                _items = _parsed_response.data
                _has_next = True

                async def _get_next():
                    return await self.list(
                        index_id,
                        page=page + 1,
                        page_limit=page_limit,
                        sort_by=sort_by,
                        sort_option=sort_option,
                        filename=filename,
                        duration=duration,
                        fps=fps,
                        width=width,
                        height=height,
                        size=size,
                        created_at=created_at,
                        updated_at=updated_at,
                        user_metadata=user_metadata,
                        request_options=request_options,
                    )

                return AsyncPager(
                    has_next=_has_next, items=_items, get_next=_get_next, response=BaseHttpResponse(response=_response)
                )
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def retrieve(
        self,
        index_id: str,
        video_id: str,
        *,
        embedding_option: typing.Optional[
            typing.Union[
                VideosRetrieveRequestEmbeddingOptionItem, typing.Sequence[VideosRetrieveRequestEmbeddingOptionItem]
            ]
        ] = None,
        transcription: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[VideosRetrieveResponse]:
        """
        <Info> This method will be deprecated in a future version. New implementations should use the [Retrieve an indexed asset](/v1.3/api-reference/index-content/retrieve) method.</Info>

        This method retrieves information about the specified video.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to retrieve.

        embedding_option : typing.Optional[typing.Union[VideosRetrieveRequestEmbeddingOptionItem, typing.Sequence[VideosRetrieveRequestEmbeddingOptionItem]]]
            Specifies which types of embeddings to retrieve. Values: `visual`, `audio`, `transcription`. For details, see the [Embedding options](/v1.3/docs/concepts/modalities#embedding-options) section.

            <Note title="Note">
            To retrieve embeddings for a video, it must be indexed using the Marengo video understanding model. For details on enabling this model for an index, see the [Create an index](/reference/create-index) page.
            </Note>

        transcription : typing.Optional[bool]
            The parameter indicates whether to retrieve a transcription of the spoken words for the indexed video.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[VideosRetrieveResponse]
            The specified video information has successfully been retrieved.
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="GET",
            params={
                "embedding_option": embedding_option,
                "transcription": transcription,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    VideosRetrieveResponse,
                    parse_obj_as(
                        type_=VideosRetrieveResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, index_id: str, video_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [Delete an indexed asset](/v1.3/api-reference/index-content/delete) method.</Info>

        This method deletes all the information about the specified indexed video. This action cannot be undone.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        index_id: str,
        video_id: str,
        *,
        user_metadata: typing.Optional[UserMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        <Info>This method will be deprecated in a future version. New implementations should use the [Partial update indexed asset](/v1.3/api-reference/index-content/update) method.</Info>

        This method updates one or more fields of the metadata of a video. Also, can delete a field by setting it to `null`.

        Parameters
        ----------
        index_id : str
            The unique identifier of the index to which the video has been uploaded.

        video_id : str
            The unique identifier of the video to update.

        user_metadata : typing.Optional[UserMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"indexes/{jsonable_encoder(index_id)}/videos/{jsonable_encoder(video_id)}",
            method="PATCH",
            json={
                "user_metadata": user_metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ReportChunkBatchResponse(UniversalBaseModel):
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL for accessing your asset. The platform returns this field only when all chunks are reported and the upload is complete. If absent, continue uploading and reporting the remaining chunks.
    """

    asset_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of this asset.
    """

    processed_chunks: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of chunks accepted from this specific request. This equals the number of chunks in your `completed_chunks` array minus any duplicates.
    """

    duplicate_chunks: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of chunks in this request that were already reported. Duplicates are ignored and don't affect your upload.
    """

    total_completed: typing.Optional[int] = pydantic.Field(default=None)
    """
    The cumulative count of all unique chunks successfully reported across all requests. When this equals `total_chunks`, the upload is complete.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .media_source import MediaSource
from .video_input_request_embedding_option_item import VideoInputRequestEmbeddingOptionItem
from .video_input_request_embedding_scope_item import VideoInputRequestEmbeddingScopeItem
from .video_input_request_embedding_type_item import VideoInputRequestEmbeddingTypeItem
from .video_segmentation import VideoSegmentation


class VideoInputRequest(UniversalBaseModel):
    """
    This field is required if the `input_type` parameter is `video`.
    """

    media_source: MediaSource
    start_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The start time in seconds for processing the video file.
    
    Use this parameter to process a portion of the video file starting from a specific time.
    
    **Default**: 0 (start from the beginning)
    """

    end_sec: typing.Optional[float] = pydantic.Field(default=None)
    """
    The end time in seconds for processing the video file.
    
    Use this parameter to process a portion of the video file ending at a specific time. The end time must be greater than the start time.
    **Default**: End of the video file
    """

    segmentation: typing.Optional[VideoSegmentation] = None
    embedding_option: typing.Optional[typing.List[VideoInputRequestEmbeddingOptionItem]] = pydantic.Field(default=None)
    """
    The types of embeddings to generate for the video.
    
    **Values:**
    - `visual`: Generates embeddings based on visual content (scenes, objects, actions)
    - `audio`: Generates embeddings based on audio content (sounds, music, effects)
    - `transcription`: Generates embeddings based on transcribed speech
    
    You can specify multiple values to generate different types of embeddings for the same video.
    
    **Default**: `["visual", "audio", "transcription"]`
    """

    embedding_scope: typing.Optional[typing.List[VideoInputRequestEmbeddingScopeItem]] = pydantic.Field(default=None)
    """
    The scope for which you wish to generate embeddings.
    
    **Values**:
    - `clip`: Generates one embedding for each segment
    - `asset`: Generates one embedding for the entire video file. Use this scope for videos up to 10-30 seconds to maintain optimal performance.
    
    You can specify multiple scopes to generate embeddings at different levels.
    
    **Default**: `["clip", "asset"]`
    """

    embedding_type: typing.Optional[typing.List[VideoInputRequestEmbeddingTypeItem]] = pydantic.Field(default=None)
    """
    Specifies how to structure the embedding. Include this parameter only when `embedding_option` contains at least two values.
    
    **Values**:
    - `separate_embedding`: Returns separate embeddings per modality specified in `embedding_option`
    - `fused_embedding`: Returns a single embedding that combines all modalities into one vector
    
    Specify both values to receive separate and fused embeddings in the same response.
    
    **Default**: `separate_embedding`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...types.next_page_token import NextPageToken
from ...types.prev_page_token import PrevPageToken
from ...types.total_inner_matches import TotalInnerMatches


class SearchRetrieveResponsePageInfo(UniversalBaseModel):
    """
    An object that provides information about pagination.
    """

    limit_per_page: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of items on each page. When grouping by video, this field represents the maximum number of videos per page. Otherwise, it represents the maximum number of video clips per page.
    """

    page_expires_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string representing the date and time, in the RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), that the page expires.
    """

    total_results: typing.Optional[int] = pydantic.Field(default=None)
    """
    The total number of results. When grouping by video, this field represents the total number of video clips matching your query. Otherwise , this field represents the total number of videos.
    """

    total_inner_matches: typing.Optional[TotalInnerMatches] = None
    next_page_token: typing.Optional[NextPageToken] = None
    prev_page_token: typing.Optional[PrevPageToken] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .asset_method import AssetMethod
from .asset_status import AssetStatus


class Asset(UniversalBaseModel):
    """
    A reference file (image, audio, or video) that you upload to the platform for use in downstream workflows such as indexing, analyzing video content, and creating entities.
    """

    id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="_id")] = pydantic.Field(default=None)
    """
    The unique identifier of the asset.
    """

    method: typing.Optional[AssetMethod] = pydantic.Field(default=None)
    """
    Indicates how you uploaded the asset.
    
    **Values**:
    - `direct`: Uploaded from your local file system
    - `url`: Uploaded from a publicly accessible URL
    """

    status: typing.Optional[AssetStatus] = pydantic.Field(default=None)
    """
    Indicates the current status of the asset.
    
    **Values**:
    - `failed`: The platform failed to process the upload
    - `processing`: The platform is processing the uploaded file
    - `ready`: The asset is ready to use
    """

    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the file used to create the asset.
    """

    file_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The MIME type of the asset file.
    """

    created_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    The date and time, in RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the asset was created.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class BaseSegment(UniversalBaseModel):
    """
    An object that contains the embedding value of a segment.
    """

    float_: typing_extensions.Annotated[typing.Optional[typing.List[float]], FieldMetadata(alias="float")] = (
        pydantic.Field(default=None)
    )
    """
    An array of floating point numbers representing the embedding. You can use this array with cosine similarity for various downstream tasks. Note that the example response was truncated for brevity.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..types.embedding_response import EmbeddingResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawEmbedClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        model_name: str,
        text: typing.Optional[str] = OMIT,
        image_url: typing.Optional[str] = OMIT,
        image_file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[core.File] = OMIT,
        audio_start_offset_sec: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EmbeddingResponse]:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>

        This method creates embeddings for text, image, and audio content.

        Ensure your media files meet the following requirements:
        - [Audio files](/v1.3/docs/concepts/models/marengo#audio-requirements).
        - [Image files](/v1.3/docs/concepts/models/marengo#image-requirements).

        Parameters for embeddings:
        - **Common parameters**:
          - `model_name`: The video understanding model you want to use. Example: "marengo3.0".
        - **Text embeddings**:
          - `text`: Text for which to create an embedding.
        - **Image embeddings**:
          Provide one of the following:
          - `image_url`: Publicly accessible URL of your image file.
          - `image_file`:  Local image file.
        - **Audio embeddings**:
          Provide one of the following:
          - `audio_url`: Publicly accessible URL of your audio file.
          - `audio_file`: Local audio file.

        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - You can create multiple types of embeddings in a single API call.
        - Audio embeddings combine generic sound and human speech in a single embedding. For videos with transcriptions, you can retrieve transcriptions and then [create text embeddings](/v1.3/api-reference/create-embeddings-v1/text-image-audio-embeddings/create-text-image-audio-embeddings) from these
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.

        text : typing.Optional[str]
            The text for which you wish to create an embedding.

            **Example**: "Man with a dog crossing the street"

        image_url : typing.Optional[str]
            The publicly accessible URL of the image for which you wish to create an embedding. This parameter is required for image embeddings if `image_file` is not provided.

        image_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            The publicly accessible URL of the audio file for which you wish to creae an embedding. This parameter is required for audio embeddings if `audio_file` is not provided.

        audio_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_start_offset_sec : typing.Optional[float]
            Specifies the start time, in seconds, from which the platform generates the audio embeddings. This parameter allows you to skip the initial portion of the audio during processing.
            **Default**: `0`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EmbeddingResponse]
            A text embedding has successfully been created.
        """
        _response = self._client_wrapper.httpx_client.request(
            "embed",
            method="POST",
            data={
                "model_name": model_name,
                "text": text,
                "image_url": image_url,
                "audio_url": audio_url,
                "audio_start_offset_sec": audio_start_offset_sec,
            },
            files={
                **({"image_file": image_file} if image_file is not None else {}),
                **({"audio_file": audio_file} if audio_file is not None else {}),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EmbeddingResponse,
                    parse_obj_as(
                        type_=EmbeddingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawEmbedClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        model_name: str,
        text: typing.Optional[str] = OMIT,
        image_url: typing.Optional[str] = OMIT,
        image_file: typing.Optional[core.File] = OMIT,
        audio_url: typing.Optional[str] = OMIT,
        audio_file: typing.Optional[core.File] = OMIT,
        audio_start_offset_sec: typing.Optional[float] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EmbeddingResponse]:
        """
        <Note title="Note">
          This endpoint will be deprecated in a future version. Migrate to the [Embed API v2](/v1.3/api-reference/create-embeddings-v2) for continued support and access to new features.
        </Note>

        This method creates embeddings for text, image, and audio content.

        Ensure your media files meet the following requirements:
        - [Audio files](/v1.3/docs/concepts/models/marengo#audio-requirements).
        - [Image files](/v1.3/docs/concepts/models/marengo#image-requirements).

        Parameters for embeddings:
        - **Common parameters**:
          - `model_name`: The video understanding model you want to use. Example: "marengo3.0".
        - **Text embeddings**:
          - `text`: Text for which to create an embedding.
        - **Image embeddings**:
          Provide one of the following:
          - `image_url`: Publicly accessible URL of your image file.
          - `image_file`:  Local image file.
        - **Audio embeddings**:
          Provide one of the following:
          - `audio_url`: Publicly accessible URL of your audio file.
          - `audio_file`: Local audio file.

        <Note title="Notes">
        - The Marengo video understanding model generates embeddings for all modalities in the same latent space. This shared space enables any-to-any searches across different types of content.
        - You can create multiple types of embeddings in a single API call.
        - Audio embeddings combine generic sound and human speech in a single embedding. For videos with transcriptions, you can retrieve transcriptions and then [create text embeddings](/v1.3/api-reference/create-embeddings-v1/text-image-audio-embeddings/create-text-image-audio-embeddings) from these
        - This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        model_name : str
            The name of the model you want to use. The following models are available:
              - `marengo3.0`: Enhanced model with sports intelligence and extended content support.

        text : typing.Optional[str]
            The text for which you wish to create an embedding.

            **Example**: "Man with a dog crossing the street"

        image_url : typing.Optional[str]
            The publicly accessible URL of the image for which you wish to create an embedding. This parameter is required for image embeddings if `image_file` is not provided.

        image_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_url : typing.Optional[str]
            The publicly accessible URL of the audio file for which you wish to creae an embedding. This parameter is required for audio embeddings if `audio_file` is not provided.

        audio_file : typing.Optional[core.File]
            See core.File for more documentation

        audio_start_offset_sec : typing.Optional[float]
            Specifies the start time, in seconds, from which the platform generates the audio embeddings. This parameter allows you to skip the initial portion of the audio during processing.
            **Default**: `0`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EmbeddingResponse]
            A text embedding has successfully been created.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "embed",
            method="POST",
            data={
                "model_name": model_name,
                "text": text,
                "image_url": image_url,
                "audio_url": audio_url,
                "audio_start_offset_sec": audio_start_offset_sec,
            },
            files={
                **({"image_file": image_file} if image_file is not None else {}),
                **({"audio_file": audio_file} if audio_file is not None else {}),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EmbeddingResponse,
                    parse_obj_as(
                        type_=EmbeddingResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ImportLogVideoStatus(UniversalBaseModel):
    """
    Counts of files in different statuses. See the [Task object](/v1.3/api-reference/upload-content/tasks/the-task-object) page details on possible values.
    """

    ready: int
    validating: int
    queued: int
    pending: int
    indexing: int
    failed: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .tasks_create_response import TasksCreateResponse
from .tasks_list_request_status_item import TasksListRequestStatusItem
from .tasks_list_response import TasksListResponse
from .tasks_list_response_page_info import TasksListResponsePageInfo
from .tasks_retrieve_response import TasksRetrieveResponse

__all__ = [
    "TasksCreateResponse",
    "TasksListRequestStatusItem",
    "TasksListResponse",
    "TasksListResponsePageInfo",
    "TasksRetrieveResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .raw_client import AsyncRawAnalyzeAsyncClient, RawAnalyzeAsyncClient
from .tasks.client import AsyncTasksClient, TasksClient


class AnalyzeAsyncClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAnalyzeAsyncClient(client_wrapper=client_wrapper)
        self.tasks = TasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAnalyzeAsyncClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAnalyzeAsyncClient
        """
        return self._raw_client


class AsyncAnalyzeAsyncClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAnalyzeAsyncClient(client_wrapper=client_wrapper)
        self.tasks = AsyncTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAnalyzeAsyncClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAnalyzeAsyncClient
        """
        return self._raw_client



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_asset_upload_request_type import CreateAssetUploadRequestType

__all__ = ["CreateAssetUploadRequestType"]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_async_embedding_request_input_type import CreateAsyncEmbeddingRequestInputType
from .create_async_embedding_request_model_name import CreateAsyncEmbeddingRequestModelName
from .tasks_create_response import TasksCreateResponse
from .tasks_create_response_status import TasksCreateResponseStatus
from .tasks_list_response import TasksListResponse
from .tasks_list_response_page_info import TasksListResponsePageInfo

__all__ = [
    "CreateAsyncEmbeddingRequestInputType",
    "CreateAsyncEmbeddingRequestModelName",
    "TasksCreateResponse",
    "TasksCreateResponseStatus",
    "TasksListResponse",
    "TasksListResponsePageInfo",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .created_at import CreatedAt
from .expires_at import ExpiresAt
from .multipart_upload_status_type import MultipartUploadStatusType


class IncompleteUploadSummary(UniversalBaseModel):
    upload_id: str = pydantic.Field()
    """
    The unique identifier of your upload session.
    """

    status: MultipartUploadStatusType
    total_size: int = pydantic.Field()
    """
    Total size of the file in bytes.
    """

    chunk_size: int = pydantic.Field()
    """
    The size of each chunk in bytes.
    """

    total_chunks: int = pydantic.Field()
    """
    The total number of chunks in this upload session.
    """

    created_at: typing.Optional[CreatedAt] = None
    expires_at: typing.Optional[ExpiresAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .chunk_info import ChunkInfo
from .created_at import CreatedAt
from .multipart_upload_status_type import MultipartUploadStatusType
from .page_info import PageInfo
from .updated_at import UpdatedAt


class GetUploadStatusResponse(UniversalBaseModel):
    upload_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of your upload session.
    """

    status: typing.Optional[MultipartUploadStatusType] = None
    uploaded_chunks: typing.Optional[typing.List[ChunkInfo]] = pydantic.Field(default=None)
    """
    Detailed status for each chunk.
    """

    chunks_completed: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of chunks successfully uploaded and reported. When this value equals `total_chunks`, the status of your upload session transitions to `completed`.
    """

    chunks_failed: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of chunks that failed to upload. If the number is greater than 0, check the `uploaded_chunks` array for specific failures and retry those chunks.
    """

    chunks_pending: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of chunks not yet successfully uploaded. This value is calculated as: `total_chunks` - `chunks_completed` - `chunks_failed`.
    """

    page_info: typing.Optional[PageInfo] = None
    total_size: typing.Optional[int] = pydantic.Field(default=None)
    """
    The size of your file in bytes. You provided this value when you created the upload session.
    """

    uploaded_size: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of bytes successfully uploaded
    """

    created_at: typing.Optional[CreatedAt] = None
    updated_at: typing.Optional[UpdatedAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .analyze_max_tokens import AnalyzeMaxTokens
from .analyze_task_error import AnalyzeTaskError
from .analyze_task_response import AnalyzeTaskResponse
from .analyze_task_result import AnalyzeTaskResult
from .analyze_task_result_usage import AnalyzeTaskResultUsage
from .analyze_task_status import AnalyzeTaskStatus
from .analyze_task_webhook_info import AnalyzeTaskWebhookInfo
from .analyze_temperature import AnalyzeTemperature
from .analyze_text_prompt import AnalyzeTextPrompt
from .asset import Asset
from .asset_method import AssetMethod
from .asset_status import AssetStatus
from .audio_embedding_metadata import AudioEmbeddingMetadata
from .audio_embedding_result import AudioEmbeddingResult
from .audio_input_request import AudioInputRequest
from .audio_input_request_embedding_option_item import AudioInputRequestEmbeddingOptionItem
from .audio_input_request_embedding_scope_item import AudioInputRequestEmbeddingScopeItem
from .audio_input_request_embedding_type_item import AudioInputRequestEmbeddingTypeItem
from .audio_segment import AudioSegment
from .audio_segmentation import AudioSegmentation
from .audio_segmentation_fixed import AudioSegmentationFixed
from .audio_segmentation_strategy import AudioSegmentationStrategy
from .bad_request_error_body import BadRequestErrorBody
from .base_embedding_metadata import BaseEmbeddingMetadata
from .base_segment import BaseSegment
from .bulk_create_entity_response import BulkCreateEntityResponse
from .bulk_create_entity_response_entities_item import BulkCreateEntityResponseEntitiesItem
from .bulk_create_entity_response_errors_item import BulkCreateEntityResponseErrorsItem
from .chunk_info import ChunkInfo
from .chunk_info_status import ChunkInfoStatus
from .completed_chunk import CompletedChunk
from .completed_chunk_proof_type import CompletedChunkProofType
from .create_analyze_task_response import CreateAnalyzeTaskResponse
from .create_asset_upload_response import CreateAssetUploadResponse
from .created_at import CreatedAt
from .embedding_audio_metadata import EmbeddingAudioMetadata
from .embedding_audio_metadata_embedding_scopes_item import EmbeddingAudioMetadataEmbeddingScopesItem
from .embedding_data import EmbeddingData
from .embedding_data_embedding_option import EmbeddingDataEmbeddingOption
from .embedding_data_embedding_scope import EmbeddingDataEmbeddingScope
from .embedding_image_metadata import EmbeddingImageMetadata
from .embedding_media_metadata import (
    EmbeddingMediaMetadata,
    EmbeddingMediaMetadata_Audio,
    EmbeddingMediaMetadata_Image,
    EmbeddingMediaMetadata_MultiInput,
    EmbeddingMediaMetadata_TextImage,
    EmbeddingMediaMetadata_Video,
)
from .embedding_multi_input_metadata import EmbeddingMultiInputMetadata
from .embedding_response import EmbeddingResponse
from .embedding_success_response import EmbeddingSuccessResponse
from .embedding_task_media_metadata import (
    EmbeddingTaskMediaMetadata,
    EmbeddingTaskMediaMetadata_Audio,
    EmbeddingTaskMediaMetadata_Video,
)
from .embedding_task_response import EmbeddingTaskResponse
from .embedding_task_response_status import EmbeddingTaskResponseStatus
from .embedding_text_image_metadata import EmbeddingTextImageMetadata
from .embedding_video_metadata import EmbeddingVideoMetadata
from .embedding_video_metadata_embedding_scopes_item import EmbeddingVideoMetadataEmbeddingScopesItem
from .end_offset_sec import EndOffsetSec
from .end_time import EndTime
from .entity import Entity
from .entity_collection import EntityCollection
from .entity_status import EntityStatus
from .error_response import ErrorResponse
from .error_response_error import ErrorResponseError
from .expires_at import ExpiresAt
from .finish_reason import FinishReason
from .forbidden_error_body import ForbiddenErrorBody
from .generated_text_data import GeneratedTextData
from .get_upload_status_response import GetUploadStatusResponse
from .hls_object import HlsObject
from .hls_object_status import HlsObjectStatus
from .image_embedding_result import ImageEmbeddingResult
from .image_input_request import ImageInputRequest
from .import_log import ImportLog
from .import_log_failed_files_item import ImportLogFailedFilesItem
from .import_log_video_status import ImportLogVideoStatus
from .incomplete_upload_summary import IncompleteUploadSummary
from .index_models_item import IndexModelsItem
from .index_schema import IndexSchema
from .indexed_asset import IndexedAsset
from .indexed_asset_detailed import IndexedAssetDetailed
from .indexed_asset_detailed_embedding import IndexedAssetDetailedEmbedding
from .indexed_asset_detailed_embedding_video_embedding import IndexedAssetDetailedEmbeddingVideoEmbedding
from .indexed_asset_status import IndexedAssetStatus
from .indexed_asset_system_metadata import IndexedAssetSystemMetadata
from .internal_entity import InternalEntity
from .internal_server_error_body import InternalServerErrorBody
from .limit_per_page_simple import LimitPerPageSimple
from .list_incomplete_uploads_response import ListIncompleteUploadsResponse
from .media_embedding_task import MediaEmbeddingTask
from .media_embedding_task_audio_embedding import MediaEmbeddingTaskAudioEmbedding
from .media_embedding_task_video_embedding import MediaEmbeddingTaskVideoEmbedding
from .media_source import MediaSource
from .multi_input_media_source import MultiInputMediaSource
from .multi_input_media_source_media_type import MultiInputMediaSourceMediaType
from .multi_input_request import MultiInputRequest
from .multipart_upload_status_type import MultipartUploadStatusType
from .next_page_token import NextPageToken
from .non_stream_analyze_response import NonStreamAnalyzeResponse
from .not_found_error_body import NotFoundErrorBody
from .one import One
from .page import Page
from .page_info import PageInfo
from .presigned_url_chunk import PresignedUrlChunk
from .prev_page_token import PrevPageToken
from .rank import Rank
from .report_chunk_batch_response import ReportChunkBatchResponse
from .request_additional_presigned_ur_ls_response import RequestAdditionalPresignedUrLsResponse
from .response_format import ResponseFormat
from .response_format_type import ResponseFormatType
from .search_item import SearchItem
from .search_item_clips_item import SearchItemClipsItem
from .search_pool import SearchPool
from .search_results import SearchResults
from .search_results_page_info import SearchResultsPageInfo
from .start_offset_sec import StartOffsetSec
from .start_time import StartTime
from .stream_analyze_response import (
    StreamAnalyzeResponse,
    StreamAnalyzeResponse_StreamEnd,
    StreamAnalyzeResponse_StreamStart,
    StreamAnalyzeResponse_TextGeneration,
)
from .stream_end_response import StreamEndResponse
from .stream_end_response_metadata import StreamEndResponseMetadata
from .stream_start_response import StreamStartResponse
from .stream_start_response_metadata import StreamStartResponseMetadata
from .stream_text_response import StreamTextResponse
from .summarize_chapter_result import SummarizeChapterResult
from .summarize_chapter_result_chapters_item import SummarizeChapterResultChaptersItem
from .summarize_chapter_result_summarize_type import SummarizeChapterResultSummarizeType
from .summarize_highlight_result import SummarizeHighlightResult
from .summarize_highlight_result_highlights_item import SummarizeHighlightResultHighlightsItem
from .summarize_highlight_result_summarize_type import SummarizeHighlightResultSummarizeType
from .summarize_summary_result import SummarizeSummaryResult
from .summarize_summary_result_summarize_type import SummarizeSummaryResultSummarizeType
from .text_embedding_result import TextEmbeddingResult
from .text_image_input_request import TextImageInputRequest
from .text_input_request import TextInputRequest
from .thumbnail_url import ThumbnailUrl
from .token_usage import TokenUsage
from .total_inner_matches import TotalInnerMatches
from .total_page import TotalPage
from .total_results import TotalResults
from .transcription_data import TranscriptionData
from .transcription_data_item import TranscriptionDataItem
from .two import Two
from .updated_at import UpdatedAt
from .url import Url
from .user_metadata import UserMetadata
from .video_context import VideoContext, VideoContext_AssetId, VideoContext_Base64String, VideoContext_Url
from .video_embedding_metadata import VideoEmbeddingMetadata
from .video_embedding_task import VideoEmbeddingTask
from .video_embedding_task_video_embedding import VideoEmbeddingTaskVideoEmbedding
from .video_indexing_task import VideoIndexingTask
from .video_indexing_task_system_metadata import VideoIndexingTaskSystemMetadata
from .video_input_request import VideoInputRequest
from .video_input_request_embedding_option_item import VideoInputRequestEmbeddingOptionItem
from .video_input_request_embedding_scope_item import VideoInputRequestEmbeddingScopeItem
from .video_input_request_embedding_type_item import VideoInputRequestEmbeddingTypeItem
from .video_item import VideoItem
from .video_item_failed import VideoItemFailed
from .video_segment import VideoSegment
from .video_segmentation import VideoSegmentation, VideoSegmentation_Dynamic, VideoSegmentation_Fixed
from .video_segmentation_dynamic import VideoSegmentationDynamic
from .video_segmentation_dynamic_dynamic import VideoSegmentationDynamicDynamic
from .video_segmentation_fixed import VideoSegmentationFixed
from .video_segmentation_fixed_fixed import VideoSegmentationFixedFixed
from .video_vector import VideoVector
from .video_vector_system_metadata import VideoVectorSystemMetadata

__all__ = [
    "AnalyzeMaxTokens",
    "AnalyzeTaskError",
    "AnalyzeTaskResponse",
    "AnalyzeTaskResult",
    "AnalyzeTaskResultUsage",
    "AnalyzeTaskStatus",
    "AnalyzeTaskWebhookInfo",
    "AnalyzeTemperature",
    "AnalyzeTextPrompt",
    "Asset",
    "AssetMethod",
    "AssetStatus",
    "AudioEmbeddingMetadata",
    "AudioEmbeddingResult",
    "AudioInputRequest",
    "AudioInputRequestEmbeddingOptionItem",
    "AudioInputRequestEmbeddingScopeItem",
    "AudioInputRequestEmbeddingTypeItem",
    "AudioSegment",
    "AudioSegmentation",
    "AudioSegmentationFixed",
    "AudioSegmentationStrategy",
    "BadRequestErrorBody",
    "BaseEmbeddingMetadata",
    "BaseSegment",
    "BulkCreateEntityResponse",
    "BulkCreateEntityResponseEntitiesItem",
    "BulkCreateEntityResponseErrorsItem",
    "ChunkInfo",
    "ChunkInfoStatus",
    "CompletedChunk",
    "CompletedChunkProofType",
    "CreateAnalyzeTaskResponse",
    "CreateAssetUploadResponse",
    "CreatedAt",
    "EmbeddingAudioMetadata",
    "EmbeddingAudioMetadataEmbeddingScopesItem",
    "EmbeddingData",
    "EmbeddingDataEmbeddingOption",
    "EmbeddingDataEmbeddingScope",
    "EmbeddingImageMetadata",
    "EmbeddingMediaMetadata",
    "EmbeddingMediaMetadata_Audio",
    "EmbeddingMediaMetadata_Image",
    "EmbeddingMediaMetadata_MultiInput",
    "EmbeddingMediaMetadata_TextImage",
    "EmbeddingMediaMetadata_Video",
    "EmbeddingMultiInputMetadata",
    "EmbeddingResponse",
    "EmbeddingSuccessResponse",
    "EmbeddingTaskMediaMetadata",
    "EmbeddingTaskMediaMetadata_Audio",
    "EmbeddingTaskMediaMetadata_Video",
    "EmbeddingTaskResponse",
    "EmbeddingTaskResponseStatus",
    "EmbeddingTextImageMetadata",
    "EmbeddingVideoMetadata",
    "EmbeddingVideoMetadataEmbeddingScopesItem",
    "EndOffsetSec",
    "EndTime",
    "Entity",
    "EntityCollection",
    "EntityStatus",
    "ErrorResponse",
    "ErrorResponseError",
    "ExpiresAt",
    "FinishReason",
    "ForbiddenErrorBody",
    "GeneratedTextData",
    "GetUploadStatusResponse",
    "HlsObject",
    "HlsObjectStatus",
    "ImageEmbeddingResult",
    "ImageInputRequest",
    "ImportLog",
    "ImportLogFailedFilesItem",
    "ImportLogVideoStatus",
    "IncompleteUploadSummary",
    "IndexModelsItem",
    "IndexSchema",
    "IndexedAsset",
    "IndexedAssetDetailed",
    "IndexedAssetDetailedEmbedding",
    "IndexedAssetDetailedEmbeddingVideoEmbedding",
    "IndexedAssetStatus",
    "IndexedAssetSystemMetadata",
    "InternalEntity",
    "InternalServerErrorBody",
    "LimitPerPageSimple",
    "ListIncompleteUploadsResponse",
    "MediaEmbeddingTask",
    "MediaEmbeddingTaskAudioEmbedding",
    "MediaEmbeddingTaskVideoEmbedding",
    "MediaSource",
    "MultiInputMediaSource",
    "MultiInputMediaSourceMediaType",
    "MultiInputRequest",
    "MultipartUploadStatusType",
    "NextPageToken",
    "NonStreamAnalyzeResponse",
    "NotFoundErrorBody",
    "One",
    "Page",
    "PageInfo",
    "PresignedUrlChunk",
    "PrevPageToken",
    "Rank",
    "ReportChunkBatchResponse",
    "RequestAdditionalPresignedUrLsResponse",
    "ResponseFormat",
    "ResponseFormatType",
    "SearchItem",
    "SearchItemClipsItem",
    "SearchPool",
    "SearchResults",
    "SearchResultsPageInfo",
    "StartOffsetSec",
    "StartTime",
    "StreamAnalyzeResponse",
    "StreamAnalyzeResponse_StreamEnd",
    "StreamAnalyzeResponse_StreamStart",
    "StreamAnalyzeResponse_TextGeneration",
    "StreamEndResponse",
    "StreamEndResponseMetadata",
    "StreamStartResponse",
    "StreamStartResponseMetadata",
    "StreamTextResponse",
    "SummarizeChapterResult",
    "SummarizeChapterResultChaptersItem",
    "SummarizeChapterResultSummarizeType",
    "SummarizeHighlightResult",
    "SummarizeHighlightResultHighlightsItem",
    "SummarizeHighlightResultSummarizeType",
    "SummarizeSummaryResult",
    "SummarizeSummaryResultSummarizeType",
    "TextEmbeddingResult",
    "TextImageInputRequest",
    "TextInputRequest",
    "ThumbnailUrl",
    "TokenUsage",
    "TotalInnerMatches",
    "TotalPage",
    "TotalResults",
    "TranscriptionData",
    "TranscriptionDataItem",
    "Two",
    "UpdatedAt",
    "Url",
    "UserMetadata",
    "VideoContext",
    "VideoContext_AssetId",
    "VideoContext_Base64String",
    "VideoContext_Url",
    "VideoEmbeddingMetadata",
    "VideoEmbeddingTask",
    "VideoEmbeddingTaskVideoEmbedding",
    "VideoIndexingTask",
    "VideoIndexingTaskSystemMetadata",
    "VideoInputRequest",
    "VideoInputRequestEmbeddingOptionItem",
    "VideoInputRequestEmbeddingScopeItem",
    "VideoInputRequestEmbeddingTypeItem",
    "VideoItem",
    "VideoItemFailed",
    "VideoSegment",
    "VideoSegmentation",
    "VideoSegmentationDynamic",
    "VideoSegmentationDynamicDynamic",
    "VideoSegmentationFixed",
    "VideoSegmentationFixedFixed",
    "VideoSegmentation_Dynamic",
    "VideoSegmentation_Fixed",
    "VideoVector",
    "VideoVectorSystemMetadata",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BadRequestErrorBody(UniversalBaseModel):
    code: typing.Optional[str] = pydantic.Field(default=None)
    """
    A string representing the code associated with the error. See the [Error codes](/v1.3/api-reference/error-codes) page for details.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    A human-readable string describing the error, intended to be suitable for display in a user interface.
    """

    docs_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL of the relevant documentation page.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .assets_create_request_method import AssetsCreateRequestMethod
from .assets_list_request_asset_types_item import AssetsListRequestAssetTypesItem
from .assets_list_response import AssetsListResponse

__all__ = ["AssetsCreateRequestMethod", "AssetsListRequestAssetTypesItem", "AssetsListResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .base_embedding_metadata import BaseEmbeddingMetadata


class VideoEmbeddingMetadata(BaseEmbeddingMetadata):
    """
    An object containing metadata associated with the embedding.
    """

    video_clip_length: typing.Optional[float] = pydantic.Field(default=None)
    """
    The duration for each clip in seconds, as specified in the request. Note that the platform automatically truncates video segments shorter than 2 seconds. For a 31-second video divided into 6-second segments, the final 1-second segment will be truncated. This truncation only applies to the last segment if it does not meet the minimum length requirement of 2 seconds.
    """

    video_embedding_scope: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The scope you've specified in the request.
    """

    duration: typing.Optional[float] = pydantic.Field(default=None)
    """
    The total duration of the video in seconds.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .audio_segment import AudioSegment
from .base_embedding_metadata import BaseEmbeddingMetadata


class AudioEmbeddingResult(UniversalBaseModel):
    """
    An object that contains the generated embedding vector and associated information.
    """

    segments: typing.Optional[typing.List[AudioSegment]] = pydantic.Field(default=None)
    """
    An object that contains the embedding and its start time.
    """

    error_message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message if the embedding generation failed.
    """

    metadata: typing.Optional[BaseEmbeddingMetadata] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class VideoSegmentationDynamicDynamic(UniversalBaseModel):
    """
    Configuration for dynamic segmentation. This object is required when `strategy` is `dynamic`.
    """

    min_duration_sec: int = pydantic.Field()
    """
    The minimum duration in seconds for each segment.
    
    The platform divides the video into segments that are at least this long. Segments adapt to scene changes and content boundaries and may be longer than the minimum.
    
    **Example**: With `min_duration_sec: 3`, segments might be: [0-3.2s], [3.2-7.8s], [7.8-12.1s]
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.analyze_max_tokens import AnalyzeMaxTokens
from ...types.analyze_task_response import AnalyzeTaskResponse
from ...types.analyze_task_status import AnalyzeTaskStatus
from ...types.analyze_temperature import AnalyzeTemperature
from ...types.analyze_text_prompt import AnalyzeTextPrompt
from ...types.create_analyze_task_response import CreateAnalyzeTaskResponse
from ...types.response_format import ResponseFormat
from ...types.video_context import VideoContext
from .raw_client import AsyncRawTasksClient, RawTasksClient
from .types.tasks_list_response import TasksListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TasksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTasksClient
        """
        return self._raw_client

    def list(
        self,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        status: typing.Optional[AnalyzeTaskStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksListResponse:
        """
        This method returns a list of the analysis tasks in your account. The platform returns your analysis tasks sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        status : typing.Optional[AnalyzeTaskStatus]
            Filter analysis tasks by status.
            Possible values: `queued`, `pending`, `processing`, `ready`, `failed`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksListResponse
            A list of analysis tasks has successfully been retrieved.

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.analyze_async.tasks.list(
            page=1,
            page_limit=10,
            status="queued",
        )
        """
        _response = self._raw_client.list(
            page=page, page_limit=page_limit, status=status, request_options=request_options
        )
        return _response.data

    def create(
        self,
        *,
        video: VideoContext,
        prompt: AnalyzeTextPrompt,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateAnalyzeTaskResponse:
        """
        This method asynchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 2 hours
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos longer than 1 hour
        - Process videos asynchronously without blocking your application

        **Do not use this method for**:
        - Videos for which you need immediate results or real-time streaming. Use the [`POST`](/v1.3/api-reference/analyze-videos/sync-analysis) method of the `/analyze` endpoint instead.

        Analyzing videos asynchronously requires three steps:

        1. Create an analysis task using this method. The platform returns a task ID.
        2. Poll the status of the task using the [`GET`](/v1.3/api-reference/analyze-videos/retrieve-analysis-task-status-results) method of the `/analyze/tasks/{task_id}` endpoint. Wait until the status is `ready`.
        3. Retrieve the results from the response when the status is `ready` using the [`GET`](/v1.3/api-reference/analyze-videos/retrieve-analysis-task-status-results) method of the `/analyze/tasks/{task_id}` endpoint.

        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        video : VideoContext

        prompt : AnalyzeTextPrompt

        temperature : typing.Optional[AnalyzeTemperature]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        response_format : typing.Optional[ResponseFormat]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateAnalyzeTaskResponse
            An analysis task has successfully been created.

        Examples
        --------
        from twelvelabs import TwelveLabs, VideoContext_Url

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.analyze_async.tasks.create(
            video=VideoContext_Url(
                url="https://example.com/video.mp4",
            ),
            prompt="Generate a detailed summary of this video in 3-4 sentences",
            temperature=0.2,
            max_tokens=1000,
        )
        """
        _response = self._raw_client.create(
            video=video,
            prompt=prompt,
            temperature=temperature,
            max_tokens=max_tokens,
            response_format=response_format,
            request_options=request_options,
        )
        return _response.data

    def retrieve(self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> AnalyzeTaskResponse:
        """
        This method retrieves the status and results of an analysis task.

        **Task statuses**:
        - `queued`: The task is waiting to be processed.
        - `pending`: The task is queued and waiting to start.
        - `processing`: The platform is analyzing the video.
        - `ready`: Processing is complete. Results are available in the response.
        - `failed`: The task failed. No results were generated.

        Poll this method until `status` is `ready` or `failed`. When `status` is `ready`, use the results from the response.

        Parameters
        ----------
        task_id : str
            The unique identifier of the analysis task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AnalyzeTaskResponse
            Task status and results retrieved successfully

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.analyze_async.tasks.retrieve(
            task_id="64f8d2c7e4a1b37f8a9c5d12",
        )
        """
        _response = self._raw_client.retrieve(task_id, request_options=request_options)
        return _response.data

    def delete(self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        This method deletes an analysis task. You can only delete tasks that are not currently being processed.

        Parameters
        ----------
        task_id : str
            The unique identifier of the analyze task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from twelvelabs import TwelveLabs

        client = TwelveLabs(
            api_key="YOUR_API_KEY",
        )
        client.analyze_async.tasks.delete(
            task_id="64f8d2c7e4a1b37f8a9c5d12",
        )
        """
        _response = self._raw_client.delete(task_id, request_options=request_options)
        return _response.data


class AsyncTasksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTasksClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTasksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTasksClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        page: typing.Optional[int] = None,
        page_limit: typing.Optional[int] = None,
        status: typing.Optional[AnalyzeTaskStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TasksListResponse:
        """
        This method returns a list of the analysis tasks in your account. The platform returns your analysis tasks sorted by creation date, with the newest at the top of the list.

        Parameters
        ----------
        page : typing.Optional[int]
            A number that identifies the page to retrieve.

            **Default**: `1`.

        page_limit : typing.Optional[int]
            The number of items to return on each page.

            **Default**: `10`.
            **Max**: `50`.

        status : typing.Optional[AnalyzeTaskStatus]
            Filter analysis tasks by status.
            Possible values: `queued`, `pending`, `processing`, `ready`, `failed`.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TasksListResponse
            A list of analysis tasks has successfully been retrieved.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.analyze_async.tasks.list(
                page=1,
                page_limit=10,
                status="queued",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            page=page, page_limit=page_limit, status=status, request_options=request_options
        )
        return _response.data

    async def create(
        self,
        *,
        video: VideoContext,
        prompt: AnalyzeTextPrompt,
        temperature: typing.Optional[AnalyzeTemperature] = OMIT,
        max_tokens: typing.Optional[AnalyzeMaxTokens] = OMIT,
        response_format: typing.Optional[ResponseFormat] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateAnalyzeTaskResponse:
        """
        This method asynchronously analyzes your videos and generates fully customizable text based on your prompts.

        <Accordion title="Input requirements">
        - Minimum duration: 4 seconds
        - Maximum duration: 2 hours
        - Formats: [FFmpeg supported formats](https://ffmpeg.org/ffmpeg-formats.html)
        - Resolution: 360x360 to 5184x2160 pixels
        - Aspect ratio: Between 1:1 and 1:2.4, or between 2.4:1 and 1:1.
        </Accordion>

        **When to use this method**:
        - Analyze videos longer than 1 hour
        - Process videos asynchronously without blocking your application

        **Do not use this method for**:
        - Videos for which you need immediate results or real-time streaming. Use the [`POST`](/v1.3/api-reference/analyze-videos/sync-analysis) method of the `/analyze` endpoint instead.

        Analyzing videos asynchronously requires three steps:

        1. Create an analysis task using this method. The platform returns a task ID.
        2. Poll the status of the task using the [`GET`](/v1.3/api-reference/analyze-videos/retrieve-analysis-task-status-results) method of the `/analyze/tasks/{task_id}` endpoint. Wait until the status is `ready`.
        3. Retrieve the results from the response when the status is `ready` using the [`GET`](/v1.3/api-reference/analyze-videos/retrieve-analysis-task-status-results) method of the `/analyze/tasks/{task_id}` endpoint.

        <Note title="Note">
        This endpoint is rate-limited. For details, see the [Rate limits](/v1.3/docs/get-started/rate-limits) page.
        </Note>

        Parameters
        ----------
        video : VideoContext

        prompt : AnalyzeTextPrompt

        temperature : typing.Optional[AnalyzeTemperature]

        max_tokens : typing.Optional[AnalyzeMaxTokens]

        response_format : typing.Optional[ResponseFormat]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateAnalyzeTaskResponse
            An analysis task has successfully been created.

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs, VideoContext_Url

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.analyze_async.tasks.create(
                video=VideoContext_Url(
                    url="https://example.com/video.mp4",
                ),
                prompt="Generate a detailed summary of this video in 3-4 sentences",
                temperature=0.2,
                max_tokens=1000,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            video=video,
            prompt=prompt,
            temperature=temperature,
            max_tokens=max_tokens,
            response_format=response_format,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(
        self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AnalyzeTaskResponse:
        """
        This method retrieves the status and results of an analysis task.

        **Task statuses**:
        - `queued`: The task is waiting to be processed.
        - `pending`: The task is queued and waiting to start.
        - `processing`: The platform is analyzing the video.
        - `ready`: Processing is complete. Results are available in the response.
        - `failed`: The task failed. No results were generated.

        Poll this method until `status` is `ready` or `failed`. When `status` is `ready`, use the results from the response.

        Parameters
        ----------
        task_id : str
            The unique identifier of the analysis task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AnalyzeTaskResponse
            Task status and results retrieved successfully

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.analyze_async.tasks.retrieve(
                task_id="64f8d2c7e4a1b37f8a9c5d12",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(task_id, request_options=request_options)
        return _response.data

    async def delete(self, task_id: str, *, request_options: typing.Optional[RequestOptions] = None) -> None:
        """
        This method deletes an analysis task. You can only delete tasks that are not currently being processed.

        Parameters
        ----------
        task_id : str
            The unique identifier of the analyze task.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from twelvelabs import AsyncTwelveLabs

        client = AsyncTwelveLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.analyze_async.tasks.delete(
                task_id="64f8d2c7e4a1b37f8a9c5d12",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(task_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .analyze_task_error import AnalyzeTaskError
from .analyze_task_result import AnalyzeTaskResult
from .analyze_task_status import AnalyzeTaskStatus
from .analyze_task_webhook_info import AnalyzeTaskWebhookInfo


class AnalyzeTaskResponse(UniversalBaseModel):
    """
    Represents the status and results of an analysis task.
    """

    task_id: str = pydantic.Field()
    """
    The unique identifier of the analysis task.
    """

    status: AnalyzeTaskStatus
    created_at: dt.datetime = pydantic.Field()
    """
    A string representing the date and time, in RFC 3339 format (“YYYY-MM-DDTHH:mm:ssZ”), when the analysis task was created.
    """

    completed_at: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    A string representing the date and time, in RFC 3339 format ("YYYY-MM-DDTHH:mm:ssZ"), when the analysis task was completed or failed. The platform returns this field only if `status` is `ready` or `failed`.
    """

    result: typing.Optional[AnalyzeTaskResult] = pydantic.Field(default=None)
    """
    An object that contains the generated text and additional information. The platform returns this object only when `status` is `ready`.
    """

    error: typing.Optional[AnalyzeTaskError] = pydantic.Field(default=None)
    """
    Details about why the task failed. The platform returns this object only when `status` is `failed`.
    """

    webhooks: typing.Optional[typing.List[AnalyzeTaskWebhookInfo]] = pydantic.Field(default=None)
    """
    The delivery status of each webhook endpoint. The platform omits this field when no webhooks are configured. You can register webhooks through the Playground. See the [Webhooks](/v1.3/docs/advanced/webhooks) page for details.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class NotFoundErrorBody(UniversalBaseModel):
    code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Represents the code associated with the error. See the [Error codes](/v1.3/api-reference/error-codes) page for details.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    A human-readable string describing the error.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class EntitiesCreateBulkRequestEntitiesItem(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    The name of the entity.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional description of the entity.
    """

    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Optional metadata for the entity, provided as key-value pairs.
    """

    asset_ids: typing.List[str] = pydantic.Field()
    """
    An array of asset IDs to associate with the entity. At least one asset ID is required.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from .entity import Entity


class InternalEntity(Entity):
    """
    An object that extends the Entity schema with additional collection information.
    """

    entity_collection_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique identifier of the entity collection the entity belongs to.
    """

    entity_collection_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the entity collection the entity belongs to.
    """

    asset_urls: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    An array of URLs for the assets associated with the entity.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
